@@ -58,7 +58,11 @@ sub index {
     my @definitions = map {
         [
             [ module_link( $_, \%opt ) ],
-            [ [ Plain [ Str $modules->{$_}->metavalue('subtitle') // '' ] ] ]
+            [
+                [
+                    Plain [ Str( $modules->{$_}->metavalue('subtitle') // '' ) ]
+                ]
+            ]
         ]
     } sort keys %$modules;
 
